@@ -1,12 +1,7 @@
 from django.contrib.auth.base_user import AbstractBaseUser
 from django.db import models
 from django.db.models import CASCADE
-
-# ugettext variants removed in Django 4.0. Only gettext now available
-try:
-    from django.utils.translation import ugettext_lazy as _
-except ImportError:
-    from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from waffle.models import AbstractBaseSample, AbstractBaseSwitch, AbstractUserFlag, CACHE_EMPTY
 from waffle.utils import get_setting, keyfmt, get_cache
@@ -50,14 +45,14 @@ class CompanyAwareFlag(AbstractUserFlag):
     )
 
     def get_flush_keys(self, flush_keys=None):
-        flush_keys = super(CompanyAwareFlag, self).get_flush_keys(flush_keys)
+        flush_keys = super().get_flush_keys(flush_keys)
         companies_cache_key = get_setting(CompanyAwareFlag.FLAG_COMPANIES_CACHE_KEY,
                                           CompanyAwareFlag.FLAG_COMPANIES_CACHE_KEY_DEFAULT)
         flush_keys.append(keyfmt(companies_cache_key, self.name))
         return flush_keys
 
     def is_active_for_user(self, user):
-        is_active = super(CompanyAwareFlag, self).is_active_for_user(user)
+        is_active = super().is_active_for_user(user)
         if is_active:
             return is_active
 
