@@ -80,7 +80,6 @@ if JINJA_INSTALLED:
                 'undefined': 'jinja2.Undefined',
                 'extensions': [
                     'jinja2.ext.i18n',
-                    'jinja2.ext.autoescape',
                     'waffle.jinja.WaffleExtension',
                 ],
             }
@@ -107,4 +106,5 @@ WAFFLE_SWITCH_DEFAULT = False
 WAFFLE_SAMPLE_DEFAULT = False
 WAFFLE_READ_FROM_WRITE_DB = False
 WAFFLE_OVERRIDE = False
+WAFFLE_ENABLE_ADMIN_PAGES = True
 WAFFLE_CACHE_PREFIX = 'test:'
