@@ -6,13 +6,14 @@ from django.utils.html import escape
 from django.utils.translation import gettext_lazy as _
 
 from waffle.models import Flag, Sample, Switch
+from waffle.utils import get_setting
 
 
 class BaseAdmin(admin.ModelAdmin):
     search_fields = ('name', 'note')
 
     def get_actions(self, request):
-        actions = super(BaseAdmin, self).get_actions(request)
+        actions = super().get_actions(request)
         if 'delete_selected' in actions:
             del actions['delete_selected']
         return actions
@@ -96,7 +97,7 @@ class FlagAdmin(BaseAdmin):
                                                  self.admin_site,
                                                  using=kwargs.get("using"))
             return db_field.formfield(**kwargs)
-        return super(FlagAdmin, self).formfield_for_dbfield(db_field, **kwargs)
+        return super().formfield_for_dbfield(db_field, **kwargs)
 
 
 def enable_switches(ma, request, qs):
@@ -133,6 +134,7 @@ class SampleAdmin(BaseAdmin):
     ordering = ('-id',)
 
 
-admin.site.register(Flag, FlagAdmin)
-admin.site.register(Sample, SampleAdmin)
-admin.site.register(Switch, SwitchAdmin)
+if get_setting('ENABLE_ADMIN_PAGES'):
+    admin.site.register(Flag, FlagAdmin)
+    admin.site.register(Sample, SampleAdmin)
+    admin.site.register(Switch, SwitchAdmin)
