@@ -8,7 +8,12 @@ from django.db import models, router, transaction
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 
-from waffle import managers, get_waffle_flag_model
+from waffle import (
+    get_waffle_sample_model,
+    get_waffle_switch_model,
+    get_waffle_flag_model,
+    managers,
+)
 from waffle.utils import get_setting, keyfmt, get_cache
 
 logger = logging.getLogger('waffle')
@@ -19,7 +24,7 @@ class BaseModel(models.Model):
     SINGLE_CACHE_KEY = ''
     ALL_CACHE_KEY = ''
 
-    class Meta(object):
+    class Meta:
         abstract = True
 
     def __str__(self):
@@ -93,7 +98,7 @@ class BaseModel(models.Model):
 
     def save(self, *args, **kwargs):
         self.modified = timezone.now()
-        ret = super(BaseModel, self).save(*args, **kwargs)
+        ret = super().save(*args, **kwargs)
         if hasattr(transaction, 'on_commit'):
             transaction.on_commit(self.flush)
         else:
@@ -101,7 +106,7 @@ class BaseModel(models.Model):
         return ret
 
     def delete(self, *args, **kwargs):
-        ret = super(BaseModel, self).delete(*args, **kwargs)
+        ret = super().delete(*args, **kwargs)
         if hasattr(transaction, 'on_commit'):
             transaction.on_commit(self.flush)
         else:
@@ -337,7 +342,7 @@ class AbstractUserFlag(AbstractBaseFlag):
         verbose_name_plural = _('Flags')
 
     def get_flush_keys(self, flush_keys=None):
-        flush_keys = super(AbstractUserFlag, self).get_flush_keys(flush_keys)
+        flush_keys = super().get_flush_keys(flush_keys)
         flush_keys.extend([
             keyfmt(get_setting('FLAG_USERS_CACHE_KEY'), self.name),
             keyfmt(get_setting('FLAG_GROUPS_CACHE_KEY'), self.name),
@@ -379,7 +384,7 @@ class AbstractUserFlag(AbstractBaseFlag):
         return group_ids
 
     def is_active_for_user(self, user):
-        is_active = super(AbstractUserFlag, self).is_active_for_user(user)
+        is_active = super().is_active_for_user(user)
         if is_active:
             return is_active
 
@@ -460,11 +465,8 @@ class AbstractBaseSwitch(BaseModel):
             if log_level:
                 logger.log(log_level, 'Switch %s not found', self.name)
             if get_setting('CREATE_MISSING_SWITCHES'):
-                switch, _created = Switch.objects.get_or_create(
-                    name=self.name,
-                    defaults={
-                        'active': get_setting('SWITCH_DEFAULT')
-                    }
+                switch, _created = get_waffle_switch_model().objects.get_or_create(
+                    name=self.name, defaults={"active": get_setting("SWITCH_DEFAULT")}
                 )
                 cache = get_cache()
                 cache.set(self._cache_key(self.name), switch)
@@ -531,11 +533,8 @@ class AbstractBaseSample(BaseModel):
 
                 default_percent = 100 if get_setting('SAMPLE_DEFAULT') else 0
 
-                sample, _created = Sample.objects.get_or_create(
-                    name=self.name,
-                    defaults={
-                        'percent': default_percent
-                    }
+                sample, _created = get_waffle_sample_model().objects.get_or_create(
+                    name=self.name, defaults={"percent": default_percent}
                 )
                 cache = get_cache()
                 cache.set(self._cache_key(self.name), sample)
